@@ -1,8 +1,8 @@
 package Git::Helpers::CPAN;
-our $VERSION = '1.000000';
+our $VERSION = '1.000001';
 use Moo;
 
-use MetaCPAN::Client ();
+use MetaCPAN::Client 2.029000 ();
 use Try::Tiny qw( try );
 use Types::Standard qw( HashRef InstanceOf Maybe Str );
 
@@ -97,7 +97,7 @@ Git::Helpers::CPAN - Get repository information for a CPAN module or release
 
 =head1 VERSION
 
-version 1.000000
+version 1.000001
 
 =head1 SYNOPSIS
 
